Module properties
stageleft
0.13.2
Module properties
Module Items
Traits
In crate stageleft
stageleft
Module
properties
Traits

Property
A “property builder”, which can accumulate annotations on a quoted snippet through chained function calls that may change the builder’s type.